summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorOwen Taylor <otaylor@redhat.com>2001-04-17 19:19:09 +0000
committerOwen Taylor <otaylor@src.gnome.org>2001-04-17 19:19:09 +0000
commiteced7172800dd6a5ec5cd5dfca15c4eb80e4b915 (patch)
treee55bdef263bc1b01d8d9cdf59161094ba4c7685b
parentca2a67b4c6fbed8d99559ab68326f866bb472a89 (diff)
downloadgdk-pixbuf-eced7172800dd6a5ec5cd5dfca15c4eb80e4b915.tar.gz
Don't put -lgthread in GLIB_LIBS, GLIB_DEPLIBS
Tue Apr 17 13:47:12 2001 Owen Taylor <otaylor@redhat.com> * configure.in: Don't put -lgthread in GLIB_LIBS, GLIB_DEPLIBS * gtk/gtktypeutils.h gtk/gtksignals.h: Restore proper parameter names to compatibility #defines so docs work. * gtk/gtkenums.h: Remove GtkMenuFactoryType * gtk/gtkwindow.c gtk/gtkdnd.c: Docs cleanups. * configure.in: Don't include -lgthread in GLIB_LIBS, GLIB_DEPLIBS * tests/testgtkrc: No magenta cursors, please. * README.in INSTALL.in HACKING README.cvs-commits: Updated. * gtk/gtkenums.h (enum): Remove left over GtkMenuFactoryType.
-rw-r--r--ChangeLog33
-rw-r--r--ChangeLog.pre-2-033
-rw-r--r--ChangeLog.pre-2-1033
-rw-r--r--ChangeLog.pre-2-233
-rw-r--r--ChangeLog.pre-2-433
-rw-r--r--ChangeLog.pre-2-633
-rw-r--r--ChangeLog.pre-2-833
-rw-r--r--HACKING19
-rw-r--r--INSTALL6
-rw-r--r--INSTALL.in26
-rw-r--r--README8
-rw-r--r--README.cvs-commits17
-rw-r--r--README.in69
-rw-r--r--configure.in4
-rw-r--r--gtk/gtkdnd.c8
-rw-r--r--gtk/gtkenums.h7
-rw-r--r--gtk/gtksignal.h68
-rw-r--r--gtk/gtktypeutils.h8
-rw-r--r--gtk/gtkwindow.c1
-rw-r--r--tests/testgtkrc2
20 files changed, 333 insertions, 141 deletions
diff --git a/ChangeLog b/ChangeLog
index 78365aa47..918509a94 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,36 @@
+Tue Apr 17 13:47:12 2001 Owen Taylor <otaylor@redhat.com>
+
+ * configure.in: Don't put -lgthread in GLIB_LIBS, GLIB_DEPLIBS
+
+ * gtk/gtktypeutils.h gtk/gtksignals.h: Restore proper parameter
+ names to compatibility #defines so docs work.
+
+ * gtk/gtkenums.h: Remove GtkMenuFactoryType
+
+ * gtk/gtkwindow.c gtk/gtkdnd.c: Docs cleanups.
+
+ * configure.in: Don't include -lgthread in GLIB_LIBS, GLIB_DEPLIBS
+
+ * tests/testgtkrc: No magenta cursors, please.
+
+ * README.in INSTALL.in HACKING README.cvs-commits: Updated.
+
+ * gtk/gtkenums.h (enum): Remove left over GtkMenuFactoryType.
+
+Mon Apr 16 14:38:41 2001 Owen Taylor <otaylor@redhat.com>
+
+ * gtk/gtklist.c gtk/gtklistitem.c: Remove explicit pointer
+ grabs, since they are no longer necessary.
+
+ * gtk/gtkcombo.c (gtk_combo_popup_button_press): Fix #52926
+ by signal_connect() and call gtk_button_pressed() rather
+ than signal_connect_after().
+
+ * tests/testgtk.c: Restore radio menu items to combos
+ since they'll look OK with Raleigh, and it is easier
+ than finishing the process of removing them that was
+ started earlier.
+
2001-04-16 Hans Breuer <hans@breuer.org>
* gdk/gdk.def :
diff --git a/ChangeLog.pre-2-0 b/ChangeLog.pre-2-0
index 78365aa47..918509a94 100644
--- a/ChangeLog.pre-2-0
+++ b/ChangeLog.pre-2-0
@@ -1,3 +1,36 @@
+Tue Apr 17 13:47:12 2001 Owen Taylor <otaylor@redhat.com>
+
+ * configure.in: Don't put -lgthread in GLIB_LIBS, GLIB_DEPLIBS
+
+ * gtk/gtktypeutils.h gtk/gtksignals.h: Restore proper parameter
+ names to compatibility #defines so docs work.
+
+ * gtk/gtkenums.h: Remove GtkMenuFactoryType
+
+ * gtk/gtkwindow.c gtk/gtkdnd.c: Docs cleanups.
+
+ * configure.in: Don't include -lgthread in GLIB_LIBS, GLIB_DEPLIBS
+
+ * tests/testgtkrc: No magenta cursors, please.
+
+ * README.in INSTALL.in HACKING README.cvs-commits: Updated.
+
+ * gtk/gtkenums.h (enum): Remove left over GtkMenuFactoryType.
+
+Mon Apr 16 14:38:41 2001 Owen Taylor <otaylor@redhat.com>
+
+ * gtk/gtklist.c gtk/gtklistitem.c: Remove explicit pointer
+ grabs, since they are no longer necessary.
+
+ * gtk/gtkcombo.c (gtk_combo_popup_button_press): Fix #52926
+ by signal_connect() and call gtk_button_pressed() rather
+ than signal_connect_after().
+
+ * tests/testgtk.c: Restore radio menu items to combos
+ since they'll look OK with Raleigh, and it is easier
+ than finishing the process of removing them that was
+ started earlier.
+
2001-04-16 Hans Breuer <hans@breuer.org>
* gdk/gdk.def :
diff --git a/ChangeLog.pre-2-10 b/ChangeLog.pre-2-10
index 78365aa47..918509a94 100644
--- a/ChangeLog.pre-2-10
+++ b/ChangeLog.pre-2-10
@@ -1,3 +1,36 @@
+Tue Apr 17 13:47:12 2001 Owen Taylor <otaylor@redhat.com>
+
+ * configure.in: Don't put -lgthread in GLIB_LIBS, GLIB_DEPLIBS
+
+ * gtk/gtktypeutils.h gtk/gtksignals.h: Restore proper parameter
+ names to compatibility #defines so docs work.
+
+ * gtk/gtkenums.h: Remove GtkMenuFactoryType
+
+ * gtk/gtkwindow.c gtk/gtkdnd.c: Docs cleanups.
+
+ * configure.in: Don't include -lgthread in GLIB_LIBS, GLIB_DEPLIBS
+
+ * tests/testgtkrc: No magenta cursors, please.
+
+ * README.in INSTALL.in HACKING README.cvs-commits: Updated.
+
+ * gtk/gtkenums.h (enum): Remove left over GtkMenuFactoryType.
+
+Mon Apr 16 14:38:41 2001 Owen Taylor <otaylor@redhat.com>
+
+ * gtk/gtklist.c gtk/gtklistitem.c: Remove explicit pointer
+ grabs, since they are no longer necessary.
+
+ * gtk/gtkcombo.c (gtk_combo_popup_button_press): Fix #52926
+ by signal_connect() and call gtk_button_pressed() rather
+ than signal_connect_after().
+
+ * tests/testgtk.c: Restore radio menu items to combos
+ since they'll look OK with Raleigh, and it is easier
+ than finishing the process of removing them that was
+ started earlier.
+
2001-04-16 Hans Breuer <hans@breuer.org>
* gdk/gdk.def :
diff --git a/ChangeLog.pre-2-2 b/ChangeLog.pre-2-2
index 78365aa47..918509a94 100644
--- a/ChangeLog.pre-2-2
+++ b/ChangeLog.pre-2-2
@@ -1,3 +1,36 @@
+Tue Apr 17 13:47:12 2001 Owen Taylor <otaylor@redhat.com>
+
+ * configure.in: Don't put -lgthread in GLIB_LIBS, GLIB_DEPLIBS
+
+ * gtk/gtktypeutils.h gtk/gtksignals.h: Restore proper parameter
+ names to compatibility #defines so docs work.
+
+ * gtk/gtkenums.h: Remove GtkMenuFactoryType
+
+ * gtk/gtkwindow.c gtk/gtkdnd.c: Docs cleanups.
+
+ * configure.in: Don't include -lgthread in GLIB_LIBS, GLIB_DEPLIBS
+
+ * tests/testgtkrc: No magenta cursors, please.
+
+ * README.in INSTALL.in HACKING README.cvs-commits: Updated.
+
+ * gtk/gtkenums.h (enum): Remove left over GtkMenuFactoryType.
+
+Mon Apr 16 14:38:41 2001 Owen Taylor <otaylor@redhat.com>
+
+ * gtk/gtklist.c gtk/gtklistitem.c: Remove explicit pointer
+ grabs, since they are no longer necessary.
+
+ * gtk/gtkcombo.c (gtk_combo_popup_button_press): Fix #52926
+ by signal_connect() and call gtk_button_pressed() rather
+ than signal_connect_after().
+
+ * tests/testgtk.c: Restore radio menu items to combos
+ since they'll look OK with Raleigh, and it is easier
+ than finishing the process of removing them that was
+ started earlier.
+
2001-04-16 Hans Breuer <hans@breuer.org>
* gdk/gdk.def :
diff --git a/ChangeLog.pre-2-4 b/ChangeLog.pre-2-4
index 78365aa47..918509a94 100644
--- a/ChangeLog.pre-2-4
+++ b/ChangeLog.pre-2-4
@@ -1,3 +1,36 @@
+Tue Apr 17 13:47:12 2001 Owen Taylor <otaylor@redhat.com>
+
+ * configure.in: Don't put -lgthread in GLIB_LIBS, GLIB_DEPLIBS
+
+ * gtk/gtktypeutils.h gtk/gtksignals.h: Restore proper parameter
+ names to compatibility #defines so docs work.
+
+ * gtk/gtkenums.h: Remove GtkMenuFactoryType
+
+ * gtk/gtkwindow.c gtk/gtkdnd.c: Docs cleanups.
+
+ * configure.in: Don't include -lgthread in GLIB_LIBS, GLIB_DEPLIBS
+
+ * tests/testgtkrc: No magenta cursors, please.
+
+ * README.in INSTALL.in HACKING README.cvs-commits: Updated.
+
+ * gtk/gtkenums.h (enum): Remove left over GtkMenuFactoryType.
+
+Mon Apr 16 14:38:41 2001 Owen Taylor <otaylor@redhat.com>
+
+ * gtk/gtklist.c gtk/gtklistitem.c: Remove explicit pointer
+ grabs, since they are no longer necessary.
+
+ * gtk/gtkcombo.c (gtk_combo_popup_button_press): Fix #52926
+ by signal_connect() and call gtk_button_pressed() rather
+ than signal_connect_after().
+
+ * tests/testgtk.c: Restore radio menu items to combos
+ since they'll look OK with Raleigh, and it is easier
+ than finishing the process of removing them that was
+ started earlier.
+
2001-04-16 Hans Breuer <hans@breuer.org>
* gdk/gdk.def :
diff --git a/ChangeLog.pre-2-6 b/ChangeLog.pre-2-6
index 78365aa47..918509a94 100644
--- a/ChangeLog.pre-2-6
+++ b/ChangeLog.pre-2-6
@@ -1,3 +1,36 @@
+Tue Apr 17 13:47:12 2001 Owen Taylor <otaylor@redhat.com>
+
+ * configure.in: Don't put -lgthread in GLIB_LIBS, GLIB_DEPLIBS
+
+ * gtk/gtktypeutils.h gtk/gtksignals.h: Restore proper parameter
+ names to compatibility #defines so docs work.
+
+ * gtk/gtkenums.h: Remove GtkMenuFactoryType
+
+ * gtk/gtkwindow.c gtk/gtkdnd.c: Docs cleanups.
+
+ * configure.in: Don't include -lgthread in GLIB_LIBS, GLIB_DEPLIBS
+
+ * tests/testgtkrc: No magenta cursors, please.
+
+ * README.in INSTALL.in HACKING README.cvs-commits: Updated.
+
+ * gtk/gtkenums.h (enum): Remove left over GtkMenuFactoryType.
+
+Mon Apr 16 14:38:41 2001 Owen Taylor <otaylor@redhat.com>
+
+ * gtk/gtklist.c gtk/gtklistitem.c: Remove explicit pointer
+ grabs, since they are no longer necessary.
+
+ * gtk/gtkcombo.c (gtk_combo_popup_button_press): Fix #52926
+ by signal_connect() and call gtk_button_pressed() rather
+ than signal_connect_after().
+
+ * tests/testgtk.c: Restore radio menu items to combos
+ since they'll look OK with Raleigh, and it is easier
+ than finishing the process of removing them that was
+ started earlier.
+
2001-04-16 Hans Breuer <hans@breuer.org>
* gdk/gdk.def :
diff --git a/ChangeLog.pre-2-8 b/ChangeLog.pre-2-8
index 78365aa47..918509a94 100644
--- a/ChangeLog.pre-2-8
+++ b/ChangeLog.pre-2-8
@@ -1,3 +1,36 @@
+Tue Apr 17 13:47:12 2001 Owen Taylor <otaylor@redhat.com>
+
+ * configure.in: Don't put -lgthread in GLIB_LIBS, GLIB_DEPLIBS
+
+ * gtk/gtktypeutils.h gtk/gtksignals.h: Restore proper parameter
+ names to compatibility #defines so docs work.
+
+ * gtk/gtkenums.h: Remove GtkMenuFactoryType
+
+ * gtk/gtkwindow.c gtk/gtkdnd.c: Docs cleanups.
+
+ * configure.in: Don't include -lgthread in GLIB_LIBS, GLIB_DEPLIBS
+
+ * tests/testgtkrc: No magenta cursors, please.
+
+ * README.in INSTALL.in HACKING README.cvs-commits: Updated.
+
+ * gtk/gtkenums.h (enum): Remove left over GtkMenuFactoryType.
+
+Mon Apr 16 14:38:41 2001 Owen Taylor <otaylor@redhat.com>
+
+ * gtk/gtklist.c gtk/gtklistitem.c: Remove explicit pointer
+ grabs, since they are no longer necessary.
+
+ * gtk/gtkcombo.c (gtk_combo_popup_button_press): Fix #52926
+ by signal_connect() and call gtk_button_pressed() rather
+ than signal_connect_after().
+
+ * tests/testgtk.c: Restore radio menu items to combos
+ since they'll look OK with Raleigh, and it is easier
+ than finishing the process of removing them that was
+ started earlier.
+
2001-04-16 Hans Breuer <hans@breuer.org>
* gdk/gdk.def :
diff --git a/HACKING b/HACKING
index 1f30aeda7..80d8ea25e 100644
--- a/HACKING
+++ b/HACKING
@@ -41,16 +41,15 @@ to autogen.sh and they will be passed on to configure.
If at all possible, please use CVS to get the latest development version of
gtk+ and glib. You can do the following to get glib and gtk+ from cvs:
- $ export CVSROOT=':pserver:anonymous@cvs.gimp.org:/debian/home/gnomecvs'
+ $ export CVSROOT=':pserver:anonymous@cvs.gnome.org:/cvs/gnome'
$ cvs login
(there is no password, just hit return)
- $ cvs -z9 checkout glib
- $ cvs -z9 checkout gtk+
-
-Please submit patches to the gtk-list@redhat.com mailing list (you must
-subscribe before you post, e-mail gtk-list-request@redhat.com with a
-subject of "subscribe"). All kinds of contributions are accepted.
-Patches that you wish to go into the distribution should also be uploaded
-to ftp://ftp.gimp.org/incoming. Follow the rules there for naming your
-patches.
+ $ cvs -z3 checkout glib
+ $ cvs -z3 checkout gtk+
+
+For information about submitting patches and commiting changes
+to CVS, see the README and README.cvs-commits files. In particular,
+don't, under any circumstances, commit anything to CVS before
+reading and understanding README.cvs-commmits.
+
diff --git a/INSTALL b/INSTALL
index 8c1b4dfdc..9cbd97c98 100644
--- a/INSTALL
+++ b/INSTALL
@@ -28,8 +28,8 @@ GTK+ requires the following packages:
Simple install procedure
========================
- % gzip -cd gtk+-1.3.3.tar.gz | tar xvf - # unpack the sources
- % cd gtk+-1.3.3 # change to the toplevel directory
+ % gzip -cd gtk+-1.3.4.tar.gz | tar xvf - # unpack the sources
+ % cd gtk+-1.3.4 # change to the toplevel directory
% ./configure # run the `configure' script
% make # build GTK
[ Become root if necessary ]
@@ -139,7 +139,7 @@ You can compile GTK+ against a copy of GLIB that you have not
yet installed. To do this, give the --with-glib=DIR options
to ./configure. For instance:
- ./configure --with-glib=../glib-1.3.3
+ ./configure --with-glib=../glib-1.3.4
This, however, will not work if you built GLIB with different
source and build directories.
diff --git a/INSTALL.in b/INSTALL.in
index e5027bd2a..adba883ae 100644
--- a/INSTALL.in
+++ b/INSTALL.in
@@ -58,11 +58,15 @@ for the XInput extension (mainly used for graphics tablets), and
which form of support to use:
no : no support
- gxi : Use generic XInput support
xfree : Use special features in the Wacom drivers in XFree86 3.3.1
and later.
+ gxi : Use generic XInput support (not recommended)
-For more information, follow the link from http://www.gtk.org
+The XInput support is not known to work with any other XServer than
+XFree86. For more information about XInput, see:
+
+ http://www.gtk.org/~otaylor/xinput/howto/index.html
+ http://www.lepied.com/xfree86/
* --disable-nls do not use Native Language Support
@@ -132,24 +136,6 @@ NLS manually to get GTK+ to compile. You can do this
by specifying the --disable-nls flag when configuring
GTK+.
-Using an uninstalled copy of GLIB [ Unsupported ]
-=================================================
-
-You can compile GTK+ against a copy of GLIB that you have not
-yet installed. To do this, give the --with-glib=DIR options
-to ./configure. For instance:
-
- ./configure --with-glib=../glib-@GTK_VERSION@
-
-This, however, will not work if you built GLIB with different
-source and build directories.
-
-It is recommended that you install GLIB before compiling
-GTK+. The --with-glib option is not regularly tested
-and may not function correctly. In addition,
-inter-library dependencies won't be generated when
-using --with-glib=.
-
Installation directories
========================
diff --git a/README b/README
index bcd4f9678..54575f3eb 100644
--- a/README
+++ b/README
@@ -1,7 +1,7 @@
General Information
===================
-This is GTK+ version 1.3.3. GTK+, which stands for the Gimp ToolKit,
+This is GTK+ version 1.3.4. GTK+, which stands for the Gimp ToolKit,
is a library for creating graphical user interfaces for the X Window
System. It is designed to be small, efficient, and flexible. GTK+ is
written in C with a very object-oriented approach.
@@ -37,9 +37,9 @@ version number. This should be separated by a blank
line from the actual headers.
Package: gtk+
- Version: 1.3.3
+ Version: 1.3.4
-[ Please substitute 1.3.3 with the version of GTK+ that
+[ Please substitute 1.3.4 with the version of GTK+ that
you have installed ]
Then describe the bug. Include:
@@ -82,7 +82,7 @@ From: yourname@your.address.org
Subject: handlebox test in testgtk is misnamed.
Package: gtk+
-Version: 1.3.3
+Version: 1.3.4
When I run gtk/testgtk, the button "handle box"
is misnamed. There are multiple handle boxes in
diff --git a/README.cvs-commits b/README.cvs-commits
index 12231d72b..ecf64a4b0 100644
--- a/README.cvs-commits
+++ b/README.cvs-commits
@@ -4,7 +4,7 @@ GTK+. This is a good thing, in that it encourages many people to work
on GTK+, and progress can be made quickly. However, GTK+ is a fairly
large and complicated package that many other things depend on, so to
avoid unnecessary breakage, and to take advantage of the knowledge
-about GTK+ that has been built up over the last 18 months, we'd like
+about GTK+ that has been built up over the last 4 years, we'd like
to ask people commiting to GTK+ to follow a few rules:
0) Ask first. If your changes are major, or could possibly break existing
@@ -14,15 +14,10 @@ to ask people commiting to GTK+ to follow a few rules:
somebody may know a better way to do things.
If you are making changes to GTK+, you should be subscribed
- to gtk-devel-list@redhat.com. (Subscription address:
- gtk-devel-list-request@redhat.com.) This is a good place to ask
+ to gtk-devel-list@gnome.org. (Subscription address:
+ gtk-devel-list-request@gnome.org.) This is a good place to ask
about intended changes.
- If you just want to make a trivial change, and don't want to subscribe,
- you can also mail gtk-bugs@gtk.org. Or, alternatively, you can look in
- the ChangeLog for somebody who has been making changes to the file
- you want to change and email them.
-
#gimp on byxnet (irc.gimp.org, irc2.gimp.org, irc3.gimp.org,
irc.germany.gimp.org...)s also a good place to find GTK+ developers to
discuss changes with, however, email to gtk-devel-list is the most
@@ -56,8 +51,4 @@ Notes:
Owen Taylor
13 Aug 1998
-
-
-
-
-
+17 Apr 2001
diff --git a/README.in b/README.in
index e0eda4c25..5ff93327d 100644
--- a/README.in
+++ b/README.in
@@ -12,11 +12,8 @@ The official ftp site is:
The official web site is:
http://www.gtk.org/
-A mailing list is located at:
- gtk-list@redhat.com
-
-To subscribe: mail -s subscribe gtk-list-request@redhat.com < /dev/null
-(Send mail to gtk-list-request@redhat.com with the subject "subscribe")
+Information about mailing lists can be found at
+ http://www.gtk.org/mailinglists.html
Installation
============
@@ -26,24 +23,12 @@ See the file 'INSTALL'
How to report bugs
==================
-Bugs should be reported to the GNOME bug tracking
-system. (http://bugs.gnome.org). To report a problem
-about GTK+, send mail to submit@bugs.gnome.org.
-
-The subject of the mail should describe your problem.
-In the body of the mail, you should first include
-a "pseudo-header" that gives the package and
-version number. This should be separated by a blank
-line from the actual headers.
-
- Package: gtk+
- Version: @GTK_VERSION@
-
-[ Please substitute @GTK_VERSION@ with the version of GTK+ that
- you have installed ]
-
-Then describe the bug. Include:
-
+Bugs should be reported to the GNOME bug tracking system.
+(http://bugzilla.gnome.org, product gtk+.) You will need
+to create an account for yourself.
+
+In the bug report please include:
+
* Information about your system. For instance:
- What operating system and version
@@ -60,11 +45,6 @@ Then describe the bug. Include:
As a last resort, you can also provide a pointer to a larger piece
of software that can be downloaded.
- (Bugs that can be reproduced within the GIMP are almost as good
- as bugs that can be reproduced in testgtk. If you are reporting a
- bug found with the GIMP, please include the version number of the GIMP
- you are using)
-
* If the bug was a crash, the exact text that was printed out
when the crash occured.
@@ -74,28 +54,19 @@ Then describe the bug. Include:
is produced running the test program with the --sync command
line option.
-An example of a bug report:
-
-====
-To: submit@bugs.gnome.org
-From: yourname@your.address.org
-Subject: handlebox test in testgtk is misnamed.
-
-Package: gtk+
-Version: @GTK_VERSION@
-
-When I run gtk/testgtk, the button "handle box"
-is misnamed. There are multiple handle boxes in
-the demo, so it should be "handle boxes", to
-be like "buttons" or "check buttons".
-===
-
Patches
=======
-Patches can be uploaded to the incoming/ directory on
-ftp.gtk.org. Please follow the instructions there, and include
-your name and email address in the README file.
+Patches should also be submitted to bugzilla.gnome.org. If the
+patch fixes an existing bug, add the patch as an attachment
+to that bug report.
+
+Otherwise, enter a new bug report that describes the patch,
+and attach the patch to that bug report.
-If the patch fixes a bug, it is usually a good idea to include
-all the information described in "How to Report Bugs".
+Bug reports containing patches should include the PATCH keyword
+in their keyword fields. If the patch adds to or changes the GTK
+programming interface, the API keyword should also be included.
+
+Patches should be in unified diff form. (The -u option to GNU
+diff.)
diff --git a/configure.in b/configure.in
index d85fa8bff..799e6c6cd 100644
--- a/configure.in
+++ b/configure.in
@@ -288,7 +288,7 @@ AC_TRY_COMPILE([#include <dirent.h>], [DIR *dir;],
# Run AM_PATH_GLIB_2_0 to make sure that GLib is installed and working
#
-GLIB_PACKAGES="gobject-2.0 gmodule-2.0 gthread-2.0"
+GLIB_PACKAGES="gobject-2.0 gmodule-2.0"
GLIB_REQUIRED_VERSION=1.3.2
AM_PATH_GLIB_2_0($GLIB_REQUIRED_VERSION, :,
@@ -297,6 +297,8 @@ AM_PATH_GLIB_2_0($GLIB_REQUIRED_VERSION, :,
*** GLIB is always available from ftp://ftp.gtk.org/.]),
gobject gmodule gthread)
+dnl Call pkg-config again since we don't want -lgthread here
+GLIB_LIBS=`$PKG_CONFIG --libs $GLIB_PACKAGES`
GLIB_DEPLIBS=$GLIB_LIBS
CFLAGS="$CFLAGS $GLIB_CFLAGS"
diff --git a/gtk/gtkenums.h b/gtk/gtkenums.h
index d9ee74bb2..43e290f28 100644
--- a/gtk/gtkenums.h
+++ b/gtk/gtkenums.h
@@ -142,13 +142,6 @@ typedef enum
typedef enum
{
- GTK_MENU_FACTORY_MENU,
- GTK_MENU_FACTORY_MENU_BAR,
- GTK_MENU_FACTORY_OPTION_MENU
-} GtkMenuFactoryType;
-
-typedef enum
-{
GTK_PIXELS,
GTK_INCHES,
GTK_CENTIMETERS
diff --git a/gtk/gtksignal.h b/gtk/gtksignal.h
index 0b8234ecd..5262401b1 100644
--- a/gtk/gtksignal.h
+++ b/gtk/gtksignal.h
@@ -44,31 +44,49 @@ extern "C" {
/* --- compat defines --- */
#define GTK_SIGNAL_OFFSET GTK_STRUCT_OFFSET
-#define gtk_signal_lookup g_signal_lookup
-#define gtk_signal_name g_signal_name
-#define gtk_signal_emit_stop(i,s) g_signal_stop_emission ((i), (s), 0)
-#define gtk_signal_connect(o,s,f,d) gtk_signal_connect_full ((o), (s), (f), 0, (d), 0, 0, 0)
-#define gtk_signal_connect_after(o,s,f,d) gtk_signal_connect_full ((o), (s), (f), 0, (d), 0, 0, 1)
-#define gtk_signal_connect_object(o,s,f,d) gtk_signal_connect_full ((o), (s), (f), 0, (d), 0, 1, 0)
-#define gtk_signal_connect_object_after(o,s,f,d) gtk_signal_connect_full ((o), (s), (f), 0, (d), 0, 1, 1)
-#define gtk_signal_disconnect g_signal_handler_disconnect
-#define gtk_signal_handler_block g_signal_handler_block
-#define gtk_signal_handler_unblock g_signal_handler_unblock
-#define gtk_signal_disconnect_by_func(o,f,d) gtk_signal_compat_matched ((o), (f), (d), G_SIGNAL_MATCH_FUNC | \
- G_SIGNAL_MATCH_DATA, 0)
-#define gtk_signal_disconnect_by_data(o,d) gtk_signal_compat_matched ((o), 0, (d), G_SIGNAL_MATCH_DATA, 0)
-#define gtk_signal_handler_block_by_func(o,f,d) gtk_signal_compat_matched ((o), (f), (d), G_SIGNAL_MATCH_FUNC | \
- G_SIGNAL_MATCH_DATA, 1)
-#define gtk_signal_handler_block_by_data(o,d) gtk_signal_compat_matched ((o), 0, (d), G_SIGNAL_MATCH_DATA, 1)
-#define gtk_signal_handler_unblock_by_func(o,f,d) gtk_signal_compat_matched ((o), (f), (d), G_SIGNAL_MATCH_FUNC | \
- G_SIGNAL_MATCH_DATA, 2)
-#define gtk_signal_handler_unblock_by_data(o,d) gtk_signal_compat_matched ((o), 0, (d), G_SIGNAL_MATCH_DATA, 2)
-#define gtk_signal_handler_pending(i,s,b) g_signal_has_handler_pending ((i), 0, (s), (b))
-#define gtk_signal_handler_pending_by_func(o,s,b,f,d) (g_signal_handler_find ((o), G_SIGNAL_MATCH_ID | \
- G_SIGNAL_MATCH_FUNC | \
- G_SIGNAL_MATCH_DATA | \
- ((b) ? 0 : G_SIGNAL_MATCH_UNBLOCKED), \
- (s), 0, 0, (f), (d)) != 0)
+#define gtk_signal_lookup(name,object_type) \
+ g_signal_lookup ((name), (object_type))
+#define gtk_signal_name(signal_id) \
+ g_signal_name (signal_id)
+#define gtk_signal_emit_stop(object,signal_id) \
+ g_signal_stop_emission ((object), (signal_id), 0)
+#define gtk_signal_connect(object,name,func,func_data) \
+ gtk_signal_connect_full ((object), (name), (func), 0, (func_data), 0, 0, 0)
+#define gtk_signal_connect_after(object,name,func,func_data) \
+ gtk_signal_connect_full ((object), (name), (func), 0, (func_data), 0, 0, 1)
+#define gtk_signal_connect_object(object,name,func,slot_object) \
+ gtk_signal_connect_full ((object), (name), (func), 0, (slot_object), 0, 1, 0)
+#define gtk_signal_connect_object_after(object,name,func,slot_object) \
+ gtk_signal_connect_full ((object), (name), (func), 0, (slot_object), 0, 1, 1)
+#define gtk_signal_disconnect(object,handler_id) \
+ g_signal_handler_disconnect ((object), (handler_id))
+#define gtk_signal_handler_block(object,handler_id) \
+ g_signal_handler_block ((object), (handler_id))
+#define gtk_signal_handler_unblock(object,handler_id) \
+ g_signal_handler_unblock ((object), (handler_id))
+#define gtk_signal_disconnect_by_func(object,func,data) \
+ gtk_signal_compat_matched ((object), (func), (data), G_SIGNAL_MATCH_FUNC | \
+ G_SIGNAL_MATCH_DATA, 0)
+#define gtk_signal_disconnect_by_data(object,data) \
+ gtk_signal_compat_matched ((object), 0, (data), G_SIGNAL_MATCH_DATA, 0)
+#define gtk_signal_handler_block_by_func(object,func,data) \
+ gtk_signal_compat_matched ((object), (func), (data), G_SIGNAL_MATCH_FUNC | \
+ G_SIGNAL_MATCH_DATA, 1)
+#define gtk_signal_handler_block_by_data(object,data) \
+ gtk_signal_compat_matched ((object), 0, (data), G_SIGNAL_MATCH_DATA, 1)
+#define gtk_signal_handler_unblock_by_func(object,func,data) \
+ gtk_signal_compat_matched ((object), (func), (data), G_SIGNAL_MATCH_FUNC | \
+ G_SIGNAL_MATCH_DATA, 2)
+#define gtk_signal_handler_unblock_by_data(object,data) \
+ gtk_signal_compat_matched ((object), 0, (data), G_SIGNAL_MATCH_DATA, 2)
+#define gtk_signal_handler_pending(object,signal_id,may_be_blocked) \
+ g_signal_has_handler_pending ((object), 0, (signal_id), (may_be_blocked))
+#define gtk_signal_handler_pending_by_func(object,signal_id,may_be_blocked,func,data) \
+ (g_signal_handler_find ((object), G_SIGNAL_MATCH_ID | \
+ G_SIGNAL_MATCH_FUNC | \
+ G_SIGNAL_MATCH_DATA | \
+ ((may_be_blocked) ? 0 : G_SIGNAL_MATCH_UNBLOCKED),\
+ (signal_id), 0, 0, (func), (data)) != 0)
/* --- compat functions --- */
diff --git a/gtk/gtktypeutils.h b/gtk/gtktypeutils.h
index ed6ff88e5..d88f7dd06 100644
--- a/gtk/gtktypeutils.h
+++ b/gtk/gtktypeutils.h
@@ -228,10 +228,10 @@ void gtk_type_init (GTypeDebugFlags debug_flags);
/* --- compatibility defines --- */
-#define gtk_type_name g_type_name
-#define gtk_type_from_name g_type_from_name
-#define gtk_type_parent g_type_parent
-#define gtk_type_is_a g_type_is_a
+#define gtk_type_name(type) g_type_name (type)
+#define gtk_type_from_name(name) g_type_from_name (name)
+#define gtk_type_parent(type) g_type_parent (type)
+#define gtk_type_is_a(type, is_a_type) g_type_is_a ((type), (is_a_type))
/* enum/flags compatibility functions, we strongly
diff --git a/gtk/gtkwindow.c b/gtk/gtkwindow.c
index 7662fb965..115b2ddea 100644
--- a/gtk/gtkwindow.c
+++ b/gtk/gtkwindow.c
@@ -3518,6 +3518,7 @@ gtk_window_begin_resize_drag (GtkWindow *window,
/**
* gtk_window_begin_move_drag:
+ * @window: a #GtkWindow
* @button: mouse button that initiated the drag
* @root_x: X position where the user clicked to initiate the drag, in root window coordinates
* @root_y: Y position where the user clicked to initiate the drag
diff --git a/tests/testgtkrc b/tests/testgtkrc
index 408cd54a6..56124a4a4 100644
--- a/tests/testgtkrc
+++ b/tests/testgtkrc
@@ -32,7 +32,7 @@ style "global-style-properties"
{
# xthickness = 20
GtkSpinButton::shadow_type = etched-out
- GtkEntry::cursor_color = "#ff00ff"
+ GtkEntry::cursor_color = "#ff0000"
}
class "GtkWidget" style "global-style-properties"
diff --git a/gtk/gtkdnd.c b/gtk/gtkdnd.c
index f6af11f6c..3b2a8b967 100644
--- a/gtk/gtkdnd.c
+++ b/gtk/gtkdnd.c
@@ -1095,7 +1095,7 @@ gtk_drag_dest_handle_event (GtkWidget *toplevel,
* gtk_drag_dest_find_target:
* @widget: drag destination widget
* @context: drag context
* @dest_target_list: list of droppable targets
*
* Looks for a match between @context->targets and the
* @dest_target_list, returning the first matching target, otherwise
@@ -1110,16 +1110,16 @@ gtk_drag_dest_handle_event (GtkWidget *toplevel,
GdkAtom
gtk_drag_dest_find_target (GtkWidget *widget,
GdkDragContext *context,
- GtkTargetList *dest_target_list)
+ GtkTargetList *target_list)
{
GList *tmp_target;
GList *tmp_source = NULL;
GtkWidget *source_widget = gtk_drag_get_source_widget (context);
- if (dest_target_list == NULL)
+ if (target_list == NULL)
return GDK_NONE;
- tmp_target = dest_target_list->list;
+ tmp_target = target_list->list;
while (tmp_target)
{
GtkTargetPair *pair = tmp_target->data;
@@ -1095,7 +1095,7 @@ gtk_drag_dest_handle_event (GtkWidget *toplevel,
* @widget: drag destination widget
* @context: drag context
- * @dest_target_list: list of droppable targets
+ * @target_list: list of droppable targets
*
* Looks for a match between @context->targets and the